.. include:: ../README.rst
    :end-before: when included in index.rst


How the documentation is structured
-----------------------------------

Documentation is split into four categories, also accessible from links in the
side-bar.

.. rst-class:: columns

`tutorials`
~~~~~~~~~~~

.. include:: tutorials.rst
    :start-after: =========

.. rst-class:: columns

`how-to`
~~~~~~~~

.. include:: how-to.rst
    :start-after: =============

.. rst-class:: columns

`explanations`
~~~~~~~~~~~~~~

.. include:: explanations.rst
    :start-after: ============

.. rst-class:: columns

`reference`
~~~~~~~~~~~

.. include:: reference.rst
    :start-after: =========

.. rst-class:: endcolumns

About the documentation
~~~~~~~~~~~~~~~~~~~~~~~

`Why is the documentation structured this way? <https://documentation.divio.com>`_
